package com.jkcredit.invoice.hub.service.rolePermission;

import com.jkcredit.invoice.hub.mapper.RolePermissionMapper;
import com.jkcredit.invoice.hub.model.dto.rolePermission.RolePermissionDto;
import com.jkcredit.invoice.hub.model.po.rolePermission.RolePermissionPo;
import com.jkcredit.invoice.hub.model.vo.rolePermission.RolePermissionVo;
import com.jkcredit.invoice.hub.service.base.BaseService;
import com.jkcredit.invoice.hub.spi.lang.exception.ServiceException;
import com.jkcredit.invoice.hub.util.BeanUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @description:
 * @author: xusonglin
 * @create: 2020/1/14 22:37
 * @version: V1.0
 **/
@Slf4j
@Service
@Transactional(readOnly = true)
public class RolePermissionServiceImpl extends BaseService implements RolePermissionService {
    @Resource
    RolePermissionMapper rolePermissionMapper;

    @Override
    @Transactional(rollbackFor = ServiceException.class)
    public void saveRolePermission(RolePermissionDto rolePermissionDto) {
        validate(rolePermissionDto);
        for (Long permissionId : rolePermissionDto.getPermissionIds()) {
            RolePermissionPo rolePermissionPo = new RolePermissionPo();
            rolePermissionPo.setRoleId(rolePermissionDto.getRoleId());
            rolePermissionPo.setPermissionId(permissionId);
            rolePermissionPo.setCreateTime(new Date());
            try {
                rolePermissionMapper.insert(rolePermissionPo);
            } catch (Exception e) {
                log.error("新增角色权限失败，失败原因：{}", e.getMessage());
                throw new ServiceException("新增角色权限失败");
            }

        }
    }

    @Override
    public List<RolePermissionVo> getPermissionsByRoleId(Long roleId) {
        List<RolePermissionPo> rolePermissionPoList = rolePermissionMapper.getPermissionsByRoleId(roleId);
        List<RolePermissionVo> rolePermissionVoList = new ArrayList<>();
        for (RolePermissionPo rolePermissionPo : rolePermissionPoList) {
            RolePermissionVo rolePermissionVo = new RolePermissionVo();
            BeanUtil.copyProperties(rolePermissionVo, rolePermissionPo);
            rolePermissionVoList.add(rolePermissionVo);
        }
        return rolePermissionVoList;
    }
}
